#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			 : http://cairo-dock.vef.fr/
# source location    : http://download.berlios.de/cairo-dock/cairo-dock-sources-2.1.1-2.tar.bz2
# last revised       : 5.11.2009
# dep                : 

softname='cairo-dock'
softversion='2.1.1_2'
softversionsrc='2.1.1-2'
packageversion='1fb'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversionsrc.tar.gz"
src="$buildir/$softname-$softversionsrc"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://launchpad.net/cairo-dock-core/2.1/2.1.1/+download/$softname-$softversionsrc.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
cairo-dock: cairo-dock (An animated application launch bar)
cairo-dock:
cairo-dock: Cairo-dock is an animated application launch bar displayed on the 
cairo-dock: desktop comparable to Mac OS X's Dock. It is compatible with Beryl, 
cairo-dock: Compiz, Metacity+xcompmgr and probably KDE since Kwin now manage 
cairo-dock: composite display.
cairo-dock: 
cairo-dock:
cairo-dock:
cairo-dock:
cairo-dock:
EOF

# check if source is present
if [ -f $softname-$softversionsrc.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

    make
    make install DESTDIR=$dest

# make icon
convert $dest/usr/share/pixmaps/$softname.svg -resize 48x48 $dest/usr/share/icons/hicolor/48x48/apps/$softname.png

sed -i -e 's/cairo-dock.svg/cairo-dock/g' $dest/usr/share/applications/$softname.desktop
sed -i -e 's/cairo-dock.svg/cairo-dock/g' $dest/usr/share/applications/$softname-cairo.desktop

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      INSTALL LICENSE\
      $dest/usr/doc/$softname-$softversion

# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,bzip2,cairo,cxxlibs|gcc-g++,dbus,dbus-glib,e2fsprogs,\
expat,fontconfig,freetype,gcc,glib2,gtk+2,gtkglext,libICE,libSM,\
libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXmu,libXrandr,libXrender,libXt,libXtst,\
libXxf86vm,libdrm,libgsf,libpng,librsvg,libxcb,libxml2,mesa,pango,\
pixman,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/cairo-dock/build-cairo-dock.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
